@@ -1014,13 +1014,13 @@ def _write_metrics(D, outputfile):
 def extract_barcodes(r1_in, r1_out, pattern1, pattern2=None, inline_umi=True,
                      data='single', keep_extracted=True, keep_discarded=True,
                      r2_in=None, r2_out=None, r3_in=None, full_match=False,
-                     separator='_', compressed=True, umilist=None):
+                     separator='_', compressed=True, umilist=None, prefix=None):
     '''
-    (list, str, str | None, str | None, bool, str, bool, bool, list | None, str | None, list | None, bool, str, bool, str | None) -> None
+    (list, str, str | None, str | None, bool, str, bool, bool, list | None, str | None, list | None, bool, str, bool, str | None, str | None) -> None
 
     Parameters
     ----------
-    
+
     - r1_in (list): Path(s) to the input FASTQ 1 (compressed or not)
     - r1_out (str): Path to the output FASTQ 1 with reads re-headered with UMI sequence 
     - pattern1 (str or None): String sequence or regular expression used for matching and extracting UMis from reads in FASTQ 1.
@@ -1044,8 +1044,13 @@ def extract_barcodes(r1_in, r1_out, pattern1, pattern2=None, inline_umi=True,
     - compressed (bool): output fastqs are compressed with gzip if True
     - umilist (str or None): Path to file with accepted barcodes. Barcodes are expected
                                in the 1st column. Any other columns are ignored.
+    - prefix (str or None): The name of output statistics files. If missing, the read 1 output basename is used.
     '''
     
+    # use read 1 output basename if prefix is None
+    if prefix is None:
+        prefix = _remove_fastq_extension(os.path.basename(r1_out))
+        
     # time function call
     start = time.time()
 
@@ -1203,8 +1208,6 @@ def extract_barcodes(r1_in, r1_out, pattern1, pattern2=None, inline_umi=True,
     d = {'total reads/pairs': Total, 'reads/pairs with matching pattern': Matching,
          'discarded reads/pairs': NonMatching, 'pattern1': pattern1, 'pattern2': pattern2,
          'umi-list file': umilist}
-    # get prefix from r1_out
-    prefix = _remove_fastq_extension(os.path.basename(r1_out))
     _write_metrics(d, os.path.join(os.path.dirname(r1_out), '{0}_extraction_metrics.json'.format(prefix)))
     _write_metrics(umi_counts, os.path.join(os.path.dirname(r1_out), '{0}_UMI_counts.json'.format(prefix)))
     
@@ -1238,6 +1241,7 @@ def main():
     e_parser.add_argument('--pattern1', dest='pattern1', help='Barcode string of regex for extracting UMIs in read 1')
     e_parser.add_argument('--pattern2', dest='pattern2', help='Barcode string of regex for extracting UMIs in read 2')
     e_parser.add_argument('--inline', dest='inline_umi', action='store_true', help='UMIs inline with reads or not. True if activated')
+    e_parser.add_argument('--prefix', dest='prefix', help='The prefix for output data files. If missing, the read 1 output basename is used')
     e_parser.add_argument('--data', dest='data', choices=['single', 'paired'], default='single', help='Paired or single end sequencing')
     e_parser.add_argument('--r2_in', dest='r2_in', nargs='*', help='Path to input FASTQ 2. Fastq 2 for paired end sequencing with inline UMIs. Fastq with UMIs for single end sequencing with UMIs not in line')
     e_parser.add_argument('--r2_out', dest='r2_out', help='Path to output FASTQ 2')
@@ -1253,8 +1257,8 @@ def main():
     
     try:
         extract_barcodes(args.r1_in, args.r1_out, pattern1=args.pattern1, pattern2=args.pattern2,
-                     inline_umi=args.inline_umi, data=args.data, keep_extracted=args.keep_extracted, keep_discarded=args.keep_discarded,
-                     r2_in=args.r2_in, r2_out=args.r2_out, r3_in=args.r3_in, full_match=args.full_match, compressed=args.compressed, umilist=args.umilist)
+        inline_umi=args.inline_umi, data=args.data, keep_extracted=args.keep_extracted, keep_discarded=args.keep_discarded,
+                     r2_in=args.r2_in, r2_out=args.r2_out, r3_in=args.r3_in, full_match=args.full_match, compressed=args.compressed, umilist=args.umilist, prefix=args.prefix)
     except AttributeError as e:
         print('#############\n')
         print('AttributeError: {0}\n'.format(e))
